
SIGNATURE_HEADER = "X-Signature"
BETA_PREFIX = 'https://apiv2.bitcoinaverage.com/'
DEV_PREFIX = 'https://apiv2-dev.bitcoinaverage.com/'
LOCAL_PREFIX = 'http://localhost:8888/'

BETA_WEBSOCKET_PREFIX = 'wss://apiv2.bitcoinaverage.com/websocket/'

WEBSOCKET_UPDATE_FREQUENCY = 3  # Send updates every 3 seconds

def construct_url(params, prefix=BETA_PREFIX):
    return '{}{}'.format(prefix, params)



from distutils.core import setup

setup(
  name = 'bitcoinaverage',
  packages = ['bitcoinaverage'], # this must be the same as the name above
  version = '0.1.0',
  description = 'Library to integrate with the BitcoinAverage API',
  author = 'Blockchain Data LTD',
  author_email = 'info@bitcoinaverage.com',
  keywords = ['bitcoinaverage', 'bitcoin', 'api'], # arbitrary keywords
  classifiers = [],
)